import queue
import time
import threading

from stomp.datastructures import Frame


class FrameDispatcher(object):
    """Dispatches incoming frames to the registered consumers
    and listeners.
    """

    def __init__(self):
        self._queue = queue.Queue()
        self._thread = threading.Thread(target=self._main_event_loop)
        self._thread.daemon = True
        self._must_exit = False
        self._thread.start()

    def handle(self, frame):
        """Handles an incoming frame."""
        raise NotImplementedError("Subclasses must override this method.")

    def _main_event_loop(self):
        while True:
            if self._must_exit:
                break
            try:
                frame = self._queue.get(False)
            except queue.Empty:
                time.sleep(0.2)
                continue
            self.handle(frame)

    def dispatch(self, frame):
        """Dispatches `frame` to consumers or listeners.

        If `frame` was published to a Queue, select a random
        consumer; if `frame` was published to a Topic, dispatch
        to all listeners.
        """
        self._queue.put(frame)

    def __call__(self, raw_frame):
        self.dispatch(Frame.fromraw(raw_frame))
