from stomp.const import EOL


class FrameType(object):
    valid_frame_types = frozenset([
        'STOMP','CONNECT','SEND','DISCONNECT','RECEIPT','MESSAGE',
        'CONNECTED','ERROR','ACK','NACK','BEGIN','ABORT','COMMIT',
        'SUBSCRIBE','UNSUBSCRIBE'
    ])

    def __init__(self, frame_type):
        """Initialize a new :class:`FrameType` instane.

        Args:
            frame_type (str): specifies the frame type.

        """
        if frame_type not in self.valid_frame_types:
            raise TypeError("Invalid frame type: {0}".format(frame_type))
        self._frame_type = frame_type

    def __eq__(self, other):
        return isinstance(other, (type(self), str)) \
            and (hash(self) == hash(other))

    def __hash__(self):
        return hash(self._frame_type)

    def __str__(self):
        return self._frame_type + EOL
