from stomp.frame.frame import Frame
from stomp.const import SEND
import stomp.headers


class Send(Frame):
    """Represents a ``SEND`` frame."""

    def __init__(self, destination, message, content_type='text/plain', 
        headers=None):
        """Initialize a new :class:`Send` instance, representing a ``SEND``
        frame.

        Args:
            destination (str): specifies the destination queue or topic.
            message (str): the message body.
            content_type (str): specifies the content type of the message;
                defaults to `"text/plain"`.
            headers (dict): additional headers to add to the message. 
        """
        default_headers = {
            stomp.headers.DESTINATION: destination,
            stomp.headers.CONTENT_LENGTH: str(len(message))
        }
        if content_type is not None:
            default_headers[stomp.headers.CONTENT_TYPE] = content_type
        headers = headers or {}
        headers.update(default_headers)
        Frame.__init__(self, SEND, headers=headers, body=message)
