from stomp import headers
from stomp.datastructures import Send
from stomp.datastructures import Subscribe


class Publisher(object):
    """Publishes frames to a specified channel."""

    def __init__(self, transport):
        self._transport = transport

    def publish(self, destination, message, content_type="text/plain",
        extra_headers=None, receipt=False):
        """Publishes a message to the specified `destination`

        Args:
            destination (str): specifies the queue or topic to
                publish to.
            message (str): the message body.
            content_type (str): specifies the content type (mimetype)
                of the message. Default is "text/plain".:w
            extra_headers (dict): a dictionary specifying 
                additional headers.
            receipt (bool): indicates if we want a receipt for
                the message.

        Returns:
            None
        """
        self._publish_message(destination, message, extra_headers or {},
            receipt=receipt)

    def subscribe(self, channel, ack='auto'):
        """Publish a ``SUBSCRIBE`` frame to the Neural server."""
        frame = Subscribe(channel, ack=ack)
        self._publish_frame(frame, receipt=True)

    def _publish_message(self, destination, message, extra_headers,
        receipt=False):
        frame = Send(destination, message, headers=extra_headers)
        for name, value in extra_headers.items():
            frame.add_header(name, value)
        self._publish_frame(frame, receipt=receipt)

    def _publish_frame(self, frame, receipt=False):
        self._transport.send_frame(frame, receipt=receipt)
